#!/bin/sh
#
# source: http://ftp.gnome.org/pub/gnome/sources/gdk-pixbuf/2.22/gdk-pixbuf-2.22.1.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='gdk-pixbuf'
softversion='2.22.1'
packageversion='66.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --disable-static \
  --enable-introspection=yes \
  --with-libjasper \
  --with-included-loaders=png

make -j4
make install DESTDIR=$dest

touch $dest/usr/lib/gdk-pixbuf-2.0/2.10.0/loaders.cache

find $dest | xargs file | grep -e "executable" -e "shared object" \
  | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

(cd $dest/usr/include
  ln -s gdk-pixbuf-2.0/gdk-pixbuf gdk-pixbuf )

# ------------------compress man pages

gzip -9 $dest/usr/man/*/*

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING NEWS $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/gdk-pixbuf html )

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

          |-----handy-ruler----------------------------------------------------|
gdk-pixbuf: gdk-pixbuf - An image loading library used with GNOME
gdk-pixbuf:
gdk-pixbuf: The gdk-pixbuf package contains an image loading library used with 
gdk-pixbuf: the GNOME GUI desktop environment. The GdkPixBuf provides image 
gdk-pixbuf: loading facilities, the rendering of a GdkPixBuf into various
gdk-pixbuf: formats (drawables or GdkRGB buffers), and a cache interface.
gdk-pixbuf:
gdk-pixbuf: 
gdk-pixbuf: 
gdk-pixbuf:
gdk-pixbuf:
EODESC

cat << "DOINST" > $dest/install/doinst.sh
  if [ -x /usr/bin/gdk-pixbuf-query-loaders ]; then
 /usr/bin/gdk-pixbuf-query-loaders --update-cache >/dev/null 2>&1
 fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5